@@ -2,9 +2,8 @@ import os
 from pathlib import Path
 from typing import Optional
 from platformdirs import user_config_dir
-from .tasker.manager import TaskManager
-from .models.machine import MachineManager
-from .models.config import ConfigManager
+from .machine.models.machine import MachineManager
+from .core.config import ConfigManager
 import logging
 
 
@@ -23,10 +22,6 @@ def getflag(name, default=False):
     return os.environ.get(name, default).lower() in ('true', '1')
 
 
-# Initialize the task manager. This is a singleton that manages all tasks.
-# It is initialized here to ensure it is available globally.
-task_mgr = TaskManager()
-
 # Load all machines. If none exist, create a default machine.
 # These are initialized to None to prevent automatic setup in subprocesses.
 # The main application must call initialize_managers() to populate them.
@@ -69,4 +64,5 @@ def initialize_managers():
             sorted(machine_mgr.machines.values(), key=lambda m: m.id)
         )[0]
         config.set_machine(machine)
+        assert config.machine
     logger.info(f"Config loaded. Using machine {config.machine.id}")
